@@ -16,7 +16,7 @@ try:
 except ImportError:
   from ordereddict import OrderedDict
 
-def updateReferenceRepoSpec(referenceSources, p, spec, fetch):
+def updateReferenceRepoSpec(referenceSources, p, spec, fetch, usePartialClone=True):
   """
   Update source reference area whenever possible, and set the spec's "reference"
   if available for reading.
@@ -26,11 +26,11 @@ def updateReferenceRepoSpec(referenceSources, p, spec, fetch):
   @spec             : the spec of the package to be updated (an OrderedDict)
   @fetch            : whether to fetch updates: if False, only clone if not found
   """
-  spec["reference"] = updateReferenceRepo(referenceSources, p, spec, fetch)
+  spec["reference"] = updateReferenceRepo(referenceSources, p, spec, fetch, usePartialClone)
   if not spec["reference"]:
     del spec["reference"]
 
-def updateReferenceRepo(referenceSources, p, spec, fetch=True):
+def updateReferenceRepo(referenceSources, p, spec, fetch=True, usePartialClone=True):
   """
   Update source reference area, if possible.
   If the area is already there and cannot be written, assume it maintained
@@ -61,26 +61,30 @@ def updateReferenceRepo(referenceSources, p, spec, fetch=True):
 
   if not is_writeable(referenceSources):
     if path.exists(referenceRepo):
-      debug("Using %s as reference for %s" % (referenceRepo, p))
+      debug("Using %s as reference for %s", referenceRepo, p)
       return referenceRepo  # reference is read-only
     else:
-      debug("Cannot create reference for %s in %s" % (p, referenceSources))
+      debug("Cannot create reference for %s in %s", p, referenceSources)
       return None  # no reference can be found and created (not fatal)
 
   err = False
+  logPath = os.path.join(dirname(referenceRepo), "fetch-log.txt")
   if not path.exists(referenceRepo):
-    cmd = ["git", "clone", partialCloneFilter, "--bare", spec["source"], referenceRepo]
+    cmd = ["git", "clone"] + (usePartialClone and [partialCloneFilter] or []) + ["--bare", spec["source"], referenceRepo]
     cmd = [x for x in cmd if x]
-    debug("Cloning reference repository: %s" % " ".join(cmd))
+    debug("Cloning reference repository: %s", " ".join(cmd))
     err = execute(cmd)
   elif fetch:
     cmd = format("cd %(referenceRepo)s && "
-                 "git fetch -f --tags %(source)s 2>&1 && "
-                 "git fetch -f %(source)s '+refs/heads/*:refs/heads/*' 2>&1",
+                 "git fetch -f --tags %(source)s >%(logPath)s 2>&1 && "
+                 "git fetch -f %(source)s '+refs/heads/*:refs/heads/*' >>%(logPath)s 2>&1",
                  referenceRepo=referenceRepo,
-                 source=spec["source"])
-    debug("Updating reference repository: %s" % cmd)
+                 source=spec["source"],
+                 logPath=logPath)
+    debug("Updating reference repository: %s", cmd)
     err = execute(cmd)
+  if os.path.exists(logPath):
+    execute("cat " + logPath)
   dieOnError(err, "Error while updating reference repos %s." % spec["source"])
   return referenceRepo  # reference is read-write
 
